@@ -3,9 +3,9 @@ package jdk.javadoc.internal.tool.resources;
 public final class version extends java.util.ListResourceBundle {
     protected final Object[][] getContents() {
         return new Object[][] {
-            { "full", "18.0.1+10" },
-            { "jdk", "18.0.1" },
-            { "release", "18.0.1" },
+            { "full", "18.0.2.1+1" },
+            { "jdk", "18.0.2.1" },
+            { "release", "18.0.2.1" },
         };
     }
 }
