@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -251,7 +247,6 @@ public class LocaleNames_ar extends OpenListResourceBundle {
             { "FR", "\u0641\u0631\u0646\u0633\u0627" },
             { "tkl", "\u0627\u0644\u062a\u0648\u0643\u064a\u0644\u0627\u0648" },
             { "grb", "\u0627\u0644\u062c\u0631\u064a\u0628\u0648" },
-            { "root", "\u0627\u0644\u062c\u0630\u0631" },
             { "type.ca.indian", "\u0627\u0644\u062a\u0642\u0648\u064a\u0645 \u0627\u0644\u0642\u0648\u0645\u064a \u0627\u0644\u0647\u0646\u062f\u064a" },
             { "grc", "\u0627\u0644\u064a\u0648\u0646\u0627\u0646\u064a\u0629 \u0627\u0644\u0642\u062f\u064a\u0645\u0629" },
             { "GA", "\u0627\u0644\u063a\u0627\u0628\u0648\u0646" },
@@ -516,7 +511,7 @@ public class LocaleNames_ar extends OpenListResourceBundle {
             { "yap", "\u0627\u0644\u064a\u0627\u0628\u064a\u0632" },
             { "TA", "\u062a\u0631\u064a\u0633\u062a\u0627\u0646 \u062f\u0627 \u0643\u0648\u0646\u0627" },
             { "asa", "\u0627\u0644\u0622\u0633\u0648" },
-            { "type.ms.ussystem", "\u0646\u0638\u0627\u0645 \u0627\u0644\u0648\u0644\u0627\u064a\u0627\u062a \u0627\u0644\u0645\u062a\u062d\u062f\u0629" },
+            { "type.ms.ussystem", "\u0646\u0638\u0627\u0645 \u0627\u0644\u0642\u064a\u0627\u0633 \u0627\u0644\u0623\u0645\u0631\u064a\u0643\u064a" },
             { "021", "\u0634\u0645\u0627\u0644 \u0623\u0645\u0631\u064a\u0643\u0627" },
             { "TC", "\u062c\u0632\u0631 \u062a\u0648\u0631\u0643\u0633 \u0648\u0643\u0627\u064a\u0643\u0648\u0633" },
             { "yav", "\u064a\u0627\u0646\u062c\u0628\u0646" },
@@ -621,7 +616,7 @@ public class LocaleNames_ar extends OpenListResourceBundle {
             { "ZW", "\u0632\u064a\u0645\u0628\u0627\u0628\u0648\u064a" },
             { "ZZ", "\u0645\u0646\u0637\u0642\u0629 \u063a\u064a\u0631 \u0645\u0639\u0631\u0648\u0641\u0629" },
             { "Runr", "\u0627\u0644\u0631\u0648\u0646\u064a" },
-            { "type.ms.metric", "\u0646\u0638\u0627\u0645 \u0645\u062a\u0631\u064a" },
+            { "type.ms.metric", "\u0627\u0644\u0646\u0638\u0627\u0645 \u0627\u0644\u0645\u062a\u0631\u064a" },
             { "type.ca.iso8601", "\u062a\u0642\u0648\u064a\u0645 ISO-8601" },
             { "lol", "\u0645\u0646\u063a\u0648\u0644\u0649" },
             { "nso", "\u0627\u0644\u0633\u0648\u062a\u0648 \u0627\u0644\u0634\u0645\u0627\u0644\u064a\u0629" },
@@ -877,7 +872,7 @@ public class LocaleNames_ar extends OpenListResourceBundle {
             { "ln", "\u0627\u0644\u0644\u064a\u0646\u062c\u0627\u0644\u0627" },
             { "fur", "\u0627\u0644\u0641\u0631\u064a\u0644\u0627\u064a\u0627\u0646" },
             { "lo", "\u0627\u0644\u0644\u0627\u0648\u064a\u0629" },
-            { "type.ms.uksystem", "\u0646\u0638\u0627\u0645 \u0627\u0644\u0645\u0645\u0644\u0643\u0629 \u0627\u0644\u0645\u062a\u062d\u062f\u0629" },
+            { "type.ms.uksystem", "\u0646\u0638\u0627\u0645 \u0627\u0644\u0642\u064a\u0627\u0633 \u0627\u0644\u0628\u0631\u064a\u0637\u0627\u0646\u064a" },
             { "lt", "\u0627\u0644\u0644\u064a\u062a\u0648\u0627\u0646\u064a\u0629" },
             { "lu", "\u0627\u0644\u0644\u0648\u0628\u0627 \u0643\u0627\u062a\u0627\u0646\u063a\u0627" },
             { "lv", "\u0627\u0644\u0644\u0627\u062a\u0641\u064a\u0629" },
